@@ -122,7 +122,7 @@ class ncell(NcellApp):
             refreshResponse = self.refreshToken()
 
             #! If token refreshed successfully, request with new token and return the response
-            if refreshResponse.responseCode == 200:
+            if refreshResponse.responseHeader['responseCode'] == 200:
                 response = requests.post(url, headers=self.headers, data=data)
                 
                 return NcellResponse(response)
@@ -703,4 +703,4 @@ class ncell(NcellApp):
 
         response = requests.post(url, headers=self.headers, data=data)
 
-        return self.__autoRefresh(response, url, data) if self.autoRefresh else NcellResponse(response)
\ No newline at end of file
+        return self.__autoRefresh(response, url, data) if self.autoRefresh else NcellResponse(response)
